@@ -6,15 +6,6 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 
-try:
-    unicode = unicode
-except NameError:
-    # 'unicode' is undefined, must be Python 3
-    basestring = (str,bytes)
-else:
-    # 'unicode' exists, must be Python 2
-    basestring = basestring
-
 from sqlalchemy import Integer, UnicodeText, Float, DateTime, Boolean, types, Table, event
 
 
@@ -81,14 +72,18 @@ def sqlite_datetime_fix():
         epoch = datetime(1970, 1, 1, 0, 0, 0)
 
         def process_bind_param(self, value, dialect):
+            if value is None:
+                return None
             if isinstance(value, datetime):
                 return value
             return (value / 1000 - self.epoch).total_seconds()
 
         def process_result_value(self, value, dialect):
-            if isinstance(value, basestring):
-                return value
-            return self.epoch + timedelta(seconds=value / 1000)
+            if value is None:
+                return None
+            if isinstance(value, int):
+                return self.epoch + timedelta(seconds=value / 1000)
+            return value
 
     def is_sqlite(inspector):
         return inspector.engine.dialect.name == "sqlite"
