@@ -7,7 +7,7 @@ try:
 except ImportError:
     from ordereddict import OrderedDict  # Python < 2.7 drop-in
 
-from sqlalchemy.exc import IntegrityError
+from sqlalchemy.exc import IntegrityError, SQLAlchemyError
 
 from dataset import connect
 from dataset.util import DatasetException
@@ -114,6 +114,16 @@ class DatabaseTestCase(unittest.TestCase):
             'string_id': 'foobar'})
         assert table.find_one(string_id='foobar')['string_id'] == 'foobar'
 
+    def test_with(self):
+        init_length = len(self.db['weather'])
+        try:
+            with self.db as tx:
+                tx['weather'].insert({'date': datetime(2011, 1, 1), 'temperature': 1, 'place': u'tmp_place'})
+                tx['weather'].insert({'date': True, 'temperature': 'wrong_value', 'place': u'tmp_place'})
+        except SQLAlchemyError:
+            pass
+        assert len(self.db['weather']) == init_length
+
     def test_load_table(self):
         tbl = self.db.load_table('weather')
         assert tbl.table == self.tbl.table
@@ -212,6 +222,10 @@ class TableTestCase(unittest.TestCase):
         assert len(ds) == 2, ds
         ds = list(self.tbl.find(place=TEST_CITY_1, _limit=1, _step=2))
         assert len(ds) == 1, ds
+        ds = list(self.tbl.find(order_by=['temperature']))
+        assert ds[0]['temperature'] == -1, ds
+        ds = list(self.tbl.find(order_by=['-temperature']))
+        assert ds[0]['temperature'] == 8, ds
 
     def test_offset(self):
         ds = list(self.tbl.find(place=TEST_CITY_1, _offset=1))
